@@ -6,8 +6,7 @@ has client => (is => 'rw', required => 1, handles => [qw/get/]);
 
 sub list {
     my ($self) = @_;
-    my $res = $self->get('/monitors');
-    return $res->data;
+    return $self->get('/monitors')->data;
 }
 
 1;
